Type Alias PSZ_R
Source pub type PSZ_R = R<u8, PSZ_A>;
pub struct PSZ_R { }
Get enumerated values variant
Checks if the value of the field is _8
Checks if the value of the field is _16
Checks if the value of the field is _32
Checks if the value of the field is _64
Checks if the value of the field is _128
Checks if the value of the field is _256
Checks if the value of the field is _512
Checks if the value of the field is _1024